'use strict';
const Schema = require('mongoose').Schema;
const metaPlugin = require('naf-framework-mongoose-free/lib/model/meta-plugin');

// 付款订单表
const payOrder = {
  openid: { type: String, required: false, zh: '微信id' }, // 其实和user_id有些重复,但是这里一定要留痕,因为有可能发生更换绑定
  school_id: { type: String, required: false, zh: '学校id', ref: 'School', getProp: [ 'name' ] }, //
  payer_id: { type: String, required: false, zh: '支付的用户id', refPath: 'payer_role' }, // 由payer_role决定是教练还是学员
  payer_role: { type: String, required: false, zh: '支付的用户角色' }, //
  pay_for: { type: String, required: false, zh: '支付原因' }, // lesson:上课,写表名等...; 学生上课(公开课/私教课):lessonStudent; 学生临时上课:tempLessonApply
  from_id: { type: String, required: false, zh: '关联id' }, // 支付原因的数据id.有就写,没有不写
  money: { type: Number, required: false, zh: '金额' }, //
  time: { type: String, required: false, zh: '时间' }, //
  order_no: { type: String, required: false, zh: '订单号' }, //
  desc: { type: String, required: false, zh: '支付说明' }, //
  status: { type: String, required: false, default: '0', zh: '支付状态' }, // 0:未支付;1:已支付;-1:支付失败;-3:已退款
  config: { type: Object, zh: '设置' },
};
const schema = new Schema(payOrder, { toJSON: { virtuals: true } });
schema.index({ id: 1 });
schema.index({ 'meta.createdAt': 1 });
schema.index({ openid: 1 });
schema.index({ school_id: 1 });
schema.index({ payer_id: 1 });
schema.index({ from_id: 1 });

schema.plugin(metaPlugin);
module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('PayOrder', schema, 'payOrder');
};
